Exclude file names containing this character string.
verbose
Flag to provide text-based progress bar.
counter
Ignored.
...
Arguments to be passed to readDICOMFile.
Value
A list structure with two major components:
img
All images
associated with the DICOM directory(ies).
hdr
All header files
associated with the DICOM directory(ies).
Details
A for loop is used to process each DICOM file contained in the
directory(ies). If only a single file is specified in the path,
readDICOM will read that file only.
References
Whitcher, B., V. J. Schmid and A. Thornton (2011). Working with
the DICOM and NIfTI Data Standards in R, Journal of Statistical
Software, 44 (6), 1--28. http://www.jstatsoft.org/v44/i06
# NOT RUN {## pixelData = TRUE## The DICOM image data are read from readDICOM()# }# NOT RUN {dcmSphere <- readDICOM(system.file("sphere3", package="oro.dicom"), verbose=TRUE)
# }