Learn R Programming

oro.dicom (version 0.2.6)

swapDimension: Reslice Data Volume Using DICOM Header Fields

Description

The input data volume (assumed to be three-dimensional) is re-sliced so that each slice is in the axial plane. Orientation is preserved so that orthographic viewing is standardized.

Usage

swapDimension(img, dcm)

Arguments

img
Multidimensional array (assumed to be three-dimensional only).
dcm
DICOM header/image object associated with the multidimensional array.

Value

  • Multidimensional array with (potentially) permuted dimensions because of the reslicing operation. An additional attribute pixdim is provided in order to facilitate conversion from DICOM to NIFTI/Analyze.

See Also

dicom2nifti, getOrientation